from setuptools import setup, find_packages

setup(
    name='unique-passwords',
    version='1.0.2',
    packages= ['unique_passwords'],
    url='https://github.com/VinayKhatrii/password',
    license='MIT',
    author='Vinay Khatri',
    author_email='khatrivinay520@gmail.com',
    description='A Python script to generate secure random passwords.',
)
